@@ -167,6 +167,6 @@ class WebServer:
             if os.path.isdir(full_file):
                 # 文件夹递归遍历
                 self.autoRegisterHandler(os.path.join(path, handler_name), ".".join([pkg_name, handler_name]))
-            elif os.path.isfile(full_file) and handler_name.endswith("handler.py"):
+            elif os.path.isfile(full_file) and handler_name.lower().endswith("handler.py"):
                 # 文件，并且为handler结尾，认为是请求处理器，完成动态装载
                 __import__("{}.{}".format(pkg_name, handler_name.replace(".py", "")))
